@@ -42,7 +42,7 @@ except (EOFError, IOError, TypeError):
     pass
 
 
-def install_npm(force):
+def install_npm(force, stdout):
     global LAST_RUN
     change_times = [0, ]
     for path in SETTINGS_PATHS:
@@ -75,6 +75,7 @@ def install_npm(force):
         app_package_change > package_change or
         force
     ):
+        stdout.write("Installing npm dependencies...")
         if not os.path.exists(TRANSPILE_CACHE_PATH):
             os.makedirs(TRANSPILE_CACHE_PATH)
         # We reload the file as other values may have changed in the meantime
@@ -118,9 +119,8 @@ class Command(BaseCommand):
         )
 
     def handle(self, *args, **options):
-        self.stdout.write("Installing npm dependencies...")
         if options["force"]:
             force = True
         else:
             force = False
-        install_npm(force)
+        install_npm(force, selfstdout)
